==> v8.3.zip: ru_twords_ru_tw/bible/other/consume.md <==
# поглощать, пожирать

## Определение:

Поглощать — значит пожирать или истреблять что-либо. Это слово может употребляться в переносном значении.

* В Библии это слово используется в значении “уничтожать”.
* Когда говорят, что “огонь поглощает всё вокруг”, это значит, что он истребляет, сжигает всё, что встречается ему на пути.
* Когда в Библии сказано, что Бог — “огнь поядающий”, это значит, что Божий гнев подобен всепоглощающему огню. Этот огонь поглощает каждого, кто не желает раскаиваться в своих беззакониях.
* Словосочетание “поглощать еду” — означает “торопливо и жадно есть”.
* Выражение “поглотить землю” можно перевести как “уничтожить землю”.

## Варианты перевода

* Когда речь идёт о земле или людях, это слово можно перевести как “уничтожать”.
* Если говорится об огне, то можно употребить слово “сжигать”.
* Горящий куст, который видел Моисей, “не был поглощаем огнём”, то есть он не сгорал.
* Когда речь идёт о еде, то слово “поглощать” можно перевести как “есть”, “пожирать”.
* Если сказано, что “сила была поглощена”, это значит, что “она была израсходована”. О человеке можно сказать, что его “силы истощились”.
* Выражение “Бог — огонь поядающий” можно перефразировать так: “Бог подобен огню, сжигающему всё вокруг” или ““Бог подобен огню, истребляющему грешников”.

(См. также: [истреблять](../other/devour.md), [гнев](../kt/wrath.md))

## Ссылки на библейский текст:

* [3 Цар. 18:38-40](rc://*/tn/help/1ki/18/38)
* [Втор. 7:16](rc://*/tn/help/deu/07/16)
* [Иер. 3:23-25](rc://*/tn/help/jer/03/23)
* [Иов 7:8-10](rc://*/tn/help/job/07/08)
* [Чис. 11:1-3](rc://*/tn/help/num/11/01)

## Данные о слове:

* Номера Стронга: H398, H402, H1086, H1104, H1197, H1497, H1846, H2000, H2628, H3615, H3617, H3631, H3857, H4127, H4529, H4743, H5486, H5487, H5595, H6244, H6789, H7332, H7646, H7829, H8046, H8552, G355, G1159, G2618, G2654, G2719, G5315, G5723

==> v9.2.zip: ru_twords_ru_tw/bible/other/consume.md <==
# поглощать, пожирать

## Определение:
Поглощать — значит пожирать или истреблять что-либо. Это слово может употребляться в переносном значении.

* В Библии это слово используется в значении “уничтожать”.
* Когда говорят, что “огонь поглощает всё вокруг”, это значит, что он истребляет, сжигает всё, что встречается ему на пути. 
* Когда в Библии сказано, что Бог — “огнь поядающий”, это значит, что Божий гнев подобен всепоглощающему огню. Этот огонь поглощает каждого, кто не желает раскаиваться в своих беззакониях. 
* Словосочетание “поглощать еду” — означает “торопливо и жадно есть”. 
* Выражение “поглотить землю” можно перевести как “уничтожить землю”.

## Варианты перевода

* Когда речь идёт о земле или людях, это слово можно перевести как “уничтожать”.
* Если говорится об огне, то можно употребить слово “сжигать”.
* Горящий куст, который видел Моисей, “не был поглощаем огнём”, то есть он не сгорал.
* Когда речь идёт о еде, то слово “поглощать” можно перевести как “есть”, “пожирать”.
* Если сказано, что “сила была поглощена”, это значит, что “она была израсходована”. О человеке можно сказать, что его “силы истощились”. 
* Выражение “Бог — огонь поядающий” можно перефразировать так: “Бог подобен огню, сжигающему всё вокруг” или ““Бог подобен огню, истребляющему грешников”.

(См. также: [истреблять](../other/devour.md), [гнев](../kt/wrath.md))

## Ссылки на библейский текст:

* [3 Цар. 18:38-40](rc://ru/tn/help/1ki/18/38)
* [Втор. 7:16](rc://ru/tn/help/deu/07/16)
* [Иер. 3:23-25](rc://ru/tn/help/jer/03/23)
* [Иов 7:8-10](rc://ru/tn/help/job/07/08)
* [Чис. 11:1-3](rc://ru/tn/help/num/11/01)

## Данные о слове:

* Номера Стронга: H398, H402, H1086, H1104, H1197, H1497, H1846, H2000, H2628, H3615, H3617, H3631, H3857, H4127, H4529, H4743, H5486, H5487, H5595, H6244, H6789, H7332, H7646, H7829, H8046, H8552, G355, G1159, G2618, G2654, G2719, G5315, G5723
